/*
 * Copyright (c) 2013 GraphAware
 *
 * This file is part of GraphAware.
 *
 * GraphAware is free software: you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 *  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of
 * the GNU General Public License along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.graphaware.neo4j.utils.iterable;

import org.neo4j.graphdb.GraphDatabaseService;
import org.neo4j.tooling.GlobalGraphOperations;

/**
 * Utility methods for dealing with {@link Iterable}s.
 */
public final class IterableUtils {

    /**
     * Count all nodes in a database.
     * <p/>
     * Please note that this can be an expensive operation! As such, it is intended mainly for testing.
     *
     * @param database in which to count nodes.
     * @return all nodes in the database (including root with ID 0, i.e. an brand new database will have 1 node).
     */
    public static int countNodes(GraphDatabaseService database) {
        return count(GlobalGraphOperations.at(database).getAllNodes());
    }

    /**
     * Count items in an iterable.
     *
     * @param iterable to count items in.
     * @return number of items in the iterable.
     */
    public static int count(Iterable iterable) {
        int result = 0;
        for (Object item : iterable) {
            result++;
        }
        return result;
    }

    private IterableUtils() {
    }
}
