package com.graphaware.neo4j.utils.tx.batch;

import java.util.concurrent.atomic.AtomicBoolean;

/**
 * {@link BatchExecutor} which expects the {@link #execute()} method to only ever be called at most once.
 * After that, it must be discarded.
 */
public abstract class DisposableBatchExecutor implements BatchExecutor {

    private final AtomicBoolean alreadyExecuted = new AtomicBoolean(false);

    /**
     * {@inheritDoc}
     */
    @Override
    public void execute() {
        if (alreadyExecuted.compareAndSet(false, true)) {
            doExecute();
        }
        else {
            throw new IllegalStateException("DisposableBatchExecutor must only ever be executed once!");
        }
    }

    /**
     * Execute work in batches.
     */
    protected abstract void doExecute();
}
